@@ -2,9 +2,10 @@ from django.contrib.auth.models import User
 from django.core.exceptions import ValidationError
 from django.core.urlresolvers import reverse
 from django.test import TestCase
-from ucamlookup import user_in_groups, get_users_from_query, return_visibleName_by_crsid, get_groups_from_query, \
+from ucamlookup.models import LookupGroup
+from ucamlookup.utils import user_in_groups, get_users_from_query, return_visibleName_by_crsid, get_groups_from_query, \
     return_title_by_groupid, get_group_ids_of_a_user_in_lookup, get_institutions, get_institution_name_by_id, \
-    LookupGroup, validate_crsids
+    validate_crsids
 
 
 class UcamLookupTests(TestCase):
@@ -15,7 +16,7 @@ class UcamLookupTests(TestCase):
         user1 = User.objects.create_user(username="amc203")
         user2 = User.objects.get(username="amc203")
         self.assertEqual(user1.id, user2.id)
-        self.assertEqual(user2.last_name, "Dr Abraham Martin-Campillo")
+        self.assertEqual(user2.last_name, "Dr Abraham Martin Campillo")
 
         with self.assertRaises(LookupGroup.DoesNotExist):
             LookupGroup.objects.get(lookup_id="101888")
@@ -36,16 +37,16 @@ class UcamLookupTests(TestCase):
         results = get_users_from_query("amc203")
         self.assertEqual(len(results), 1)
         self.assertEqual(results[0]['crsid'], "amc203")
-        self.assertEqual(results[0]['visibleName'], "Dr Abraham Martin-Campillo")
+        self.assertEqual(results[0]['visibleName'], "Dr Abraham Martin Campillo")
 
-        results = get_users_from_query("Martin-Campillo")
+        results = get_users_from_query("Martin Campillo")
         self.assertEqual(len(results), 1)
         self.assertEqual(results[0]['crsid'], "amc203")
-        self.assertEqual(results[0]['visibleName'], "Dr Abraham Martin-Campillo")
+        self.assertEqual(results[0]['visibleName'], "Dr Abraham Martin Campillo")
 
     def test_return_visibleName_by_crsid(self):
         result = return_visibleName_by_crsid("amc203")
-        self.assertEqual(result, "Dr Abraham Martin-Campillo")
+        self.assertEqual(result, "Dr Abraham Martin Campillo")
         result = return_visibleName_by_crsid("amc20311")
         self.assertEqual(result, '')
 
@@ -75,7 +76,6 @@ class UcamLookupTests(TestCase):
     def test_get_institutions_with_user(self):
         amc203 = User.objects.create_user(username="amc203")
         results = get_institutions(user=amc203)
-        self.assertIn(("CS", "University Computing Service"), results)
         self.assertIn(("UIS", "University Information Services"), results)
 
     def test_get_institution_name_by_id(self):
@@ -95,18 +95,18 @@ class UcamLookupTests(TestCase):
     def test_views_without_login(self):
         response = self.client.get(reverse('ucamlookup_find_people'), {'query': 'amc203', 'searchId_u': '1'})
         self.assertEqual(response.status_code, 302)
-        self.assertTrue(response.url.startswith('http://testserver/accounts/login/'))
+        self.assertTrue(response.url.startswith('/accounts/login/'))
         response = self.client.get(reverse('ucamlookup_find_groups'), {'query': 'Information Systems',
                                                                        'searchId_g': '1'})
         self.assertEqual(response.status_code, 302)
-        self.assertTrue(response.url.startswith('http://testserver/accounts/login/'))
+        self.assertTrue(response.url.startswith('/accounts/login/'))
 
     def test_findpeople_view(self):
         User.objects.create_user(username="amc203", password="test")
         self.assertTrue(self.client.login(username='amc203', password="test"))
         response = self.client.get(reverse('ucamlookup_find_people'), {'query': 'amc203', 'searchId_u': '1'})
         self.assertEqual(response.content,
-                         '{"persons": [{"visibleName": "Dr Abraham Martin-Campillo", "crsid": "amc203"}], '
+                         '{"persons": [{"visibleName": "Dr Abraham Martin Campillo", "crsid": "amc203"}], '
                          '"searchId_u": "1"}')
 
     def test_findgroups_view(self):
@@ -137,4 +137,4 @@ class UcamLookupTests(TestCase):
         self.assertEqual(len(user_list), 0)
 
         with self.assertRaises(ValidationError):
-            validate_crsids("kaskvdkam20e9mciasmdimadf")
\ No newline at end of file
+            validate_crsids("kaskvdkam20e9mciasmdimadf")
