@@ -1,7 +1,9 @@
+import re
 from django.contrib.auth.models import User
 from django.core.exceptions import ValidationError
-import re
-from ibisclient import *
+from ucamlookup.ibisclient import *
+from ucamlookup.models import LookupGroup
+
 
 conn = createConnection()
 
@@ -45,9 +47,36 @@ def get_group_ids_of_a_user_in_lookup(user):
     :param user: the user
     :return: the list of group_ids
     """
+    try:
+        group_list = PersonMethods(conn).getGroups(scheme="crsid", identifier=user.username)
+        return map(lambda group: group.groupid, group_list)
+    except IbisException:
+        return []
 
-    group_list = PersonMethods(conn).getGroups(scheme="crsid", identifier=user.username)
-    return map(lambda group: group.groupid, group_list)
+
+def get_or_create_group_by_groupid(groupid):
+    """ Returns the django LookupGroup object corresponding to the groupid parameter.
+        :param crsid: the groupid of the retrieved group
+    """
+    groupidstr = str(groupid)
+    group = LookupGroup.objects.filter(lookup_id=groupidstr)
+    if group.exists():
+        group = group.first()
+    else:
+        group = LookupGroup.objects.create(lookup_id=groupidstr)
+    return group
+
+
+def get_user_lookupgroups(user):
+    """ Returns the list of lookup groups of a user
+    :param user: the User
+    :return: the list of LookupGroups
+    """
+    try:
+        group_list = PersonMethods(conn).getGroups(scheme="crsid", identifier=user.username)
+        return map(lambda group: get_or_create_group_by_groupid(group.groupid), group_list)
+    except IbisException:
+        return []
 
 
 def get_institutions(user=None):
@@ -131,4 +160,14 @@ def validate_crsids(crsids_text):
         else:
             raise ValidationError("The list of users contains an invalid user")
 
-    return users
\ No newline at end of file
+    return users
+
+
+def get_users_of_a_group(group):
+    """ Returns the list of users of a LookupGroup
+    :param group: The LookupGroup
+    :return: the list of Users
+    """
+
+    return map(lambda user: get_or_create_user_by_crsid(user.identifier),
+               GroupMethods(conn).getMembers(groupid=group.groupid))
