@@ -1,7 +1,7 @@
 import json
 from django.contrib.auth.decorators import login_required
 from django.http import HttpResponse
-from utils import get_users_from_query, get_groups_from_query
+from ucamlookup.utils import get_users_from_query, get_groups_from_query
 
 
 @login_required
@@ -14,4 +14,4 @@ def find_people(request):
 def find_groups(request):
     groups = get_groups_from_query(request.GET.get('query'))
     return HttpResponse(json.dumps({'searchId_g': request.GET.get('searchId_g'), 'groups': groups}),
-                        content_type='application/json')
\ No newline at end of file
+                        content_type='application/json')
